/*
 * Local Matters Voice and Wireless Division, Inc. Confidential
 * OCO Source Materials
 * Copyright (C) Local Matters Voice and Wireless Division, Inc. 2007.  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise divested of its trade
 * secrets, irrespective of what has been deposited with the U.S. Copyright Office.
 */
package com.localmatters.collector.schema;

import java.util.List;

/**
 * The schema-manager service interface.
 *
 * @author Daniel Cavalcanti
 */
public interface SchemaService {
    
    /**
     * Adds a schema to the schema manager container. If the schema already
     * exists, it is updated.
     * 
     * @param name The schema name.
     * @param version The schema version.
     * @param schema The schema.
     * @throws java.lang.NullPointerException If any of the parameters is null.
     * @throws com.localmatters.collector.schema.InvalidSchemaException If the schema is invalid.
     * @throws com.localmatters.collector.schema.SchemaException If there is any other exception/error.
     */
    public void addSchema(String name, String version, String schema)
    throws NullPointerException, InvalidSchemaException, SchemaException;
    
    /**
     * Gets all schemas names.
     *
     * @return All schemas names.
     * @throws com.localmatters.collector.schema.SchemaException If there is any other exception/error.
     */
    public List<String> getNames()
    throws SchemaException;
    
    /**
     * Gets all schemas versions.
     *
     * @return All schemas versions.
     * @param name The schema name.
     * @throws java.lang.NullPointerException If any of the parameters is null.
     * @throws com.localmatters.collector.schema.SchemaException If there is any other exception/error.
     */
    public List<String> getVersions(String name)
    throws NullPointerException, SchemaException;
    
    /**
     * Gets a schema.
     *
     * @return The schema if it exists, null otherwise.
     * @param name The schema name.
     * @param version The schema version.
     * @throws java.lang.NullPointerException If any of the parameters is null.
     * @throws com.localmatters.collector.schema.SchemaException If there is any other exception/error.
     */
    public String getSchema(String name, String version)
    throws NullPointerException, SchemaException;
    
    /**
     * Gets all schemas.
     *
     * @return All schemas.
     * @throws com.localmatters.collector.schema.SchemaException If there is any other exception/error.
     */
    public List<String> getAllSchemas()
    throws SchemaException;
    
    /**
     * Updates a schema. If the schema does not exist, it is added to the schema
     * manager container.
     *
     * @param name The schema name.
     * @param version The schema version.
     * @param schema The schema.
     * @throws java.lang.NullPointerException If any of the parameters is null.
     * @throws com.localmatters.collector.schema.InvalidSchemaException If the schema is invalid.
     * @throws com.localmatters.collector.schema.SchemaException If there is any other exception/error.
     */
    public void updateSchema(String name, String version, String schema)
    throws NullPointerException, InvalidSchemaException, SchemaException;
    
    /**
     * Removes a schema from the schema manager container. If version is null,
     * all versions under that name are removed from the schema manager
     * container.
     *
     * @param name The schema name.
     * @param version The schema version.
     * @throws java.lang.NullPointerException If name is null.
     * @throws com.localmatters.collector.schema.SchemaException If there is any other exception/error.
     */
    public void removeSchema(String name, String version)
    throws NullPointerException, SchemaException;
    
}
