/*
 * Local Matters Voice and Wireless Division, Inc. Confidential
 * OCO Source Materials
 * Copyright (C) Local Matters Voice and Wireless Division, Inc. 2007.  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise divested of its trade
 * secrets, irrespective of what has been deposited with the U.S. Copyright Office.
 */
package com.localmatters.collector.schema.entity;

import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.EmbeddedId;
import javax.persistence.Entity;
import javax.persistence.Lob;
import javax.persistence.NamedQueries;
import javax.persistence.NamedQuery;
import javax.persistence.Table;

/**
 * Entity class CollectorSchema.
 * 
 * @author Daniel Cavalcanti
 */
@Entity
@Table(name = "collector_schemas")
public class CollectorSchema
    implements Serializable {
    
    // **********************************************************************
    // Instance variables
    // **********************************************************************
    
    /**
     * EmbeddedId primary key field.
     */
    @EmbeddedId()
    protected CollectorSchemaPK schemaPK;
    
    @Lob()
    @Column(name = "document", nullable = false)
    private String document;
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of CollectorSchema.
     */
    public CollectorSchema() {
    }
    
    /**
     * Creates a new instance of CollectorSchema with the specified values.
     * 
     * @param schemaPK the schemaPK of the SCollectorSchema
     */
    public CollectorSchema(CollectorSchemaPK schemaPK) {
        this.schemaPK = schemaPK;
    }
    
    /**
     * Creates a new instance of CollectorSchema with the specified values.
     * 
     * @param schemaPK the schemaPK of the SCollectorSchema
     * @param document the document of the ScCollectorSchema
     */
    public CollectorSchema(CollectorSchemaPK schemaPK, String document) {
        this.schemaPK = schemaPK;
        this.document = document;
    }
    
    /**
     * Creates a new instance of CollectorSchemaPK with the specified values.
     * 
     * @param version the version of the SCollectorSchemaPK
     * @param name the name of the ScCollectorSchemaPK
     */
    public CollectorSchema(String version, String name) {
        this.schemaPK = new CollectorSchemaPK(version, name);
    }
    
    // **********************************************************************
    // Getter/Setter methods
    // **********************************************************************
    
    /**
     * Gets the schemaPK of this CollectorSchema.
     * 
     * @return the schemaPK.
     */
    public CollectorSchemaPK getSchemaPK() {
        return this.schemaPK;
    }
    
    /**
     * Sets the schemaPK of this CollectorSchema to the specified value.
     * 
     * @param schemaPK the new schemaPK.
     */
    public void setSchemaPK(CollectorSchemaPK schemaPK) {
        this.schemaPK = schemaPK;
    }
    
    /**
     * Gets the document of this CollectorSchema.
     * 
     * @return the document.
     */
    public String getDocument() {
        return this.document;
    }
    
    /**
     * Sets the document of this CollectorSchema to the specified value.
     * 
     * @param document the new document.
     */
    public void setDocument(String document) {
        this.document = document;
    }
    
    // **********************************************************************
    // Entity required methods
    // **********************************************************************
    
    /**
     * Returns a hash code value for the object. This implementation computes
     * a hash code value based on the id fields in this object.
     *
     * @return a hash code value for this object.
     */
    @Override()
    public int hashCode() {
        int hash = 0;
        hash += (this.schemaPK != null ? this.schemaPK.hashCode() : 0);
        return hash;
    }
    
    /**
     * Determines whether another object is equal to this CollectorSchema. The result is
     * <code>true</code> if and only if the argument is not null and is a
     * CollectorSchema object that has the same id field values as this object.
     * 
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     *  <code>false</code> otherwise.
     */
    @Override()
    public boolean equals(Object object) {
        if (object instanceof CollectorSchema) {
            CollectorSchema other = (CollectorSchema)object;
            if (this.schemaPK != other.schemaPK && (this.schemaPK == null || !this.schemaPK.equals(other.schemaPK))) return false;
            return true;
        } else return false;
    }
    
    /**
     * Returns a string representation of the object.
     *
     * @return a string representation of the object.
     */
    @Override()
    public String toString() {
        return schemaPK.toString();
    }
    
}
