/*
 * Local Matters Voice and Wireless Division, Inc. Confidential
 * OCO Source Materials
 * Copyright (C) Local Matters Voice and Wireless Division, Inc. 2007.  All Rights Reserved.
 *
 * The source code for this program is not published or otherwise divested of its trade
 * secrets, irrespective of what has been deposited with the U.S. Copyright Office.
 */
package com.localmatters.collector.schema.entity;

import java.io.Serializable;
import javax.persistence.Column;
import javax.persistence.Embeddable;

/**
 * Primary Key class CollectorSchemaPK for entity class Schema.
 * 
 * @author Daniel Cavalcanti
 */
@Embeddable()
public class CollectorSchemaPK
    implements Serializable {
    
    // **********************************************************************
    // Instance variables
    // **********************************************************************
    
    @Column(name = "name", nullable = false)
    private String name;
    
    @Column(name = "version", nullable = false)
    private String version;
    
    // **********************************************************************
    // Constructors
    // **********************************************************************
    
    /**
     * Creates a new instance of CollectorSchemaPK.
     */
    public CollectorSchemaPK() {
    }
    
    /**
     * Creates a new instance of CollectorSchemaPK with the specified values.
     * 
     * @param version the version of the CollectorSchemaPK.
     * @param name the name of the CollectorSchemaPK.
     */
    public CollectorSchemaPK(String version, String name) {
        this.version = version;
        this.name = name;
    }
    
    // **********************************************************************
    // Getter/Setter methods
    // **********************************************************************
    
    /**
     * Gets the name of this CollectorSchemaPK.
     * 
     * @return the name.
     */
    public String getName() {
        return this.name;
    }
    
    /**
     * Sets the name of this CollectorSchemaPK to the specified value.
     * 
     * @param name the new name.
     */
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * Gets the version of this CollectorSchemaPK.
     * 
     * @return the version.
     */
    public String getVersion() {
        return this.version;
    }
    
    /**
     * Sets the version of this CollectorSchemaPK to the specified value.
     * 
     * @param version the new version.
     */
    public void setVersion(String version) {
        this.version = version;
    }
    
    // **********************************************************************
    // Entity required methods
    // **********************************************************************
    
    /**
     * Returns a hash code value for the object. This implementation computes
     * a hash code value based on the id fields in this object.
     *
     * @return a hash code value for this object.
     */
    @Override()
    public int hashCode() {
        int hash = 0;
        hash += (this.version != null ? this.version.hashCode() : 0);
        hash += (this.name != null ? this.name.hashCode() : 0);
        return hash;
    }
    
    /**
     * Determines whether another object is equal to this CollectorSchemaPK. The result
     * is <code>true</code> if and only if the argument is not null and is a
     * CollectorSchemaPK object that has the same id field values as this object.
     * 
     * @param object the reference object with which to compare
     * @return <code>true</code> if this object is the same as the argument;
     *  <code>false</code> otherwise.
     */
    @Override()
    public boolean equals(Object object) {
        if (object instanceof CollectorSchemaPK) {
            CollectorSchemaPK other = (CollectorSchemaPK)object;
            if (this.version != other.version && (this.version == null || !this.version.equals(other.version))) return false;
            if (this.name != other.name && (this.name == null || !this.name.equals(other.name))) return false;
            return true;
        } else return false;
    }
    
    /**
     * Returns a string representation of the object.
     *
     * @return a string representation of the object.
     */
    @Override()
    public String toString() {
        return name + " <" + version + ">";
    }
    
}
